@@ -1,12 +1,12 @@
 package Padre::Plugin::YAML::Document;
 
-use v5.10;
+use v5.10.1;
 use strict;
 use warnings;
 
 use Padre::Document ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.08';
 use parent qw(Padre::Document);
 
 
@@ -39,7 +39,7 @@ Padre::Plugin::YAML::Document - YAML support for Padre The Perl IDE
 
 =head1 VERSION
 
-This document describes Padre::Plugin::YAML::Document version 0.05
+version: 0.08
 
 
 =head1 DESCRIPTION
@@ -57,7 +57,6 @@ Environment.
 Syntax highlighting for YAML is supported by Padre out of the box.
 This plug-in adds some more features to deal with YAML files.
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -90,7 +89,7 @@ Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2011-2012, Zeno Gantner E<lt>zenog@cpan.orgE<gt>. All rights reserved.
+Copyright (c) 2011-2013, Zeno Gantner E<lt>zenog@cpan.orgE<gt>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
