@@ -1,19 +1,23 @@
 package Padre::Plugin::YAML::Syntax;
 
-use v5.10;
+use v5.10.1;
 use strict;
 use warnings;
 
+# turn of experimental warnings
+no if $] > 5.017010, warnings => 'experimental::smartmatch';
+
 use Padre::Logger;
 use Padre::Task::Syntax ();
 use Padre::Wx           ();
+use Try::Tiny;
 
-our $VERSION = '0.05';
+our $VERSION = '0.08';
 use parent qw(Padre::Task::Syntax);
 
 sub new {
 	my $class = shift;
-	$class->SUPER::new(@_);
+	return $class->SUPER::new(@_);
 }
 
 sub run {
@@ -35,28 +39,28 @@ sub syntax {
 
 	TRACE("\n$text") if DEBUG;
 
-	eval {
+	try {
 		if ( $^O =~ /Win32/i )
 		{
 			require YAML;
-			YAML::Load($text);
+			YAML::Load($text);	
 		} else {
 			require YAML::XS;
 			YAML::XS::Load($text);
 		}
-	};
-	if ($@) {
-		TRACE("\nInfo: from YAML::XS::Load: $@") if DEBUG;
-		if ( $^O =~ /Win32/i ) {
-			return $self->_parse_error_win32($@);
-		} else {
-			return $self->_parse_error($@);
-		}
+		# No errors...
+		return {};	
 	}
-
-	# No errors...
-	return {};
-
+	catch {
+		TRACE("\nInfo: from YAML::XS::Load:\n $_") if DEBUG;
+		if ( $^O =~ /Win32/i ) {
+			# send errors to syantax panel
+			return $self->_parse_error_win32($_);
+		} else {
+			# send errors to syantax panel
+			return $self->_parse_error($_);
+		}
+	};
 }
 
 sub _parse_error {
@@ -76,7 +80,10 @@ sub _parse_error {
 		when (/YAML::XS::Load (\w+)\: .+/) {
 			$type = $1;
 		}
-		when (/^\s+(found.+)/) {
+		when (/^\s+(block.+)/) {
+			$message = $1;
+		}
+		when (/^\s+(cannot.+)/) {
 			$message = $1;
 		}
 		when (/^\s+(could not.+)/) {
@@ -85,7 +92,7 @@ sub _parse_error {
 		when (/^\s+(did not.+)/) {
 			$message = $1;
 		}
-		when (/^\s+(block.+)/) {
+		when (/^\s+(found.+)/) {
 			$message = $1;
 		}
 		when (/^\s+(mapping.+)/) {
@@ -110,7 +117,9 @@ sub _parse_error {
 
 	push @issues,
 		{
-		message => $message . ( defined $code ? " ( $code )" : q{} ),
+		# YAML::XS dose not produce error codes, hence we can use defined or //
+		# message => $message . ( defined $code ? " ( $code )" : q{} ),
+		message => $message . ( $code // q{} ),
 		line => $line,
 		type => $type eq 'Error' ? 'F' : 'W',
 		file => $self->{filename},
@@ -163,7 +172,6 @@ sub _parse_error_win32 {
 
 __END__
 
-
 =pod
 
 =head1 NAME
@@ -173,7 +181,7 @@ Padre::Plugin::YAML::Syntax - YAML document syntax-checking in the background
 
 =head1 VERSION
 
-This document describes Padre::Plugin::YAML::Syntax version 0.05
+version: 0.08
 
 
 =head1 DESCRIPTION
@@ -216,7 +224,7 @@ Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2011-2012, Zeno Gantner E<lt>zenog@cpan.orgE<gt>. All rights reserved.
+Copyright (c) 2011-2013, Zeno Gantner E<lt>zenog@cpan.orgE<gt>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
